@@ -4,7 +4,9 @@
 import pygtk
 pygtk.require('2.0')
 from gtk import gdk
-import gtk.glade
+##import gtk.glade
+import gtk
+
 import gobject
 
 
