@@ -25,7 +25,7 @@ if not hasattr(__builtin__, '_'):
     def _(string):
         return string
 
-version =           '1.1.1'
+version =           '1.1.4'
 author =            'Jendrik Seipp'
 authorMail =        'jendrikseipp@web.de'
 url =               'http://rednotebook.sourceforge.net'
@@ -35,10 +35,10 @@ bug_url =           'https://bugs.launchpad.net/rednotebook/+filebug'
 
 developers =    ['Jendrik Seipp <jendrikseipp@web.de>',
                 '',
-                'Contributors:',
+                'Past Contributors:',
                 'Alexandre Cucumel <superkiouk@gmail.com>',
                 ]
-                
+
 comments = '''\
 RedNotebook is a graphical journal to keep track of notes and \
 thoughts. It includes a calendar navigation, customizable \
@@ -47,7 +47,7 @@ format, tag and search your entries.\
 '''
 
 license_text = '''\
-Copyright (c) 2009,2010  Jendrik Seipp
+Copyright (c) 2009,2010,2011  Jendrik Seipp
 
 RedNotebook is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -76,8 +76,11 @@ If the journal-path is omitted the last session's journal will be used.
 At the first program start this defaults to "$HOME/.rednotebook/data".
 ''' % version
 
-greeting = _('''Hello,
-this is RedNotebook, a desktop journal. Thank you very much for giving it a try.''')
+greeting = _('Hello!')
+intro=_('''Some example text has been added to help you start and \
+you can erase it whenever you like.''')
+### Translators: "Help" -> noun
+help_par = _('The example text and more documentation is available under "Help" -> "Contents".')
 overview1 = _('The interface is divided into three parts:')
 ### Translators: The location "left"
 overview21 = _('Left')
@@ -89,18 +92,23 @@ overview32 = _('Text for a day')
 overview41 = _('Right')
 overview42 = _('Annotations to a day')
 
-text_entry = _('Text entries')
-text_entry_par = _('An entry could look like this:')
+### Translators: noun
+preview = _('Preview')
+preview1 = _('''There are two modes in RedNotebook, the __editing__ mode and \
+the __preview__ mode.''')
+### Translators: Preview -> noun
+preview2 = _('Click on Preview above to see the difference.')
+preview_par = ' '.join([preview1, preview2])
+
 example_entry = _('''Today I went to the //pet shop// and bought a **tiger**. Then we went to the \
 --pool-- park and had a nice time playing \
 ultimate frisbee. Afterwards we watched "__Life of Brian__".''')
 
 annotations = _('Annotations')
-ann1 = _('On the right there is space for annotations to a day.')
-ann2 = _('Annotations are notes that can easily be sorted into categories.')
+ann2 = _('Annotations are notes that can be sorted into categories.')
 ann3 = _('''For example you could create the category "Ideas" \
 and then add today's ideas to it.''')
-ann_par = ' '.join([ann1, ann2, ann3])
+ann_par = ' '.join([ann2, ann3])
 
 templates = ('Templates')
 temp1 = ('RedNotebook supports templates.')
@@ -119,12 +127,6 @@ save4 = _('In the "Journal" menu you also find the "Export" button.')
 save5 = _('Click on "Export" and export your diary to Plain Text, HTML or Latex.')
 save_par = ' '.join([save1, save2, save3, save4, save5])
 
-### Translators: noun
-help = _('Help')
-### Translators: "Help" -> noun
-help3 = _('You can find more documentation under "Help" -> "Help".')
-help_par = ' '.join([help3])
-
 error1 = _('If you encounter any errors, please drop me a note so I can fix them.')
 error2 = _('Any feedback is appreciated.')
 error_par = ' '.join([error1, error2])
@@ -133,7 +135,8 @@ goodbye_par = _('Have a nice day!')
 
 
 completeWelcomeText = '''\
-%(greeting)s
+%(greeting)s %(intro)s %(help_par)s
+
 %(overview1)s
 
 - **%(overview21)s**: %(overview22)s
@@ -141,10 +144,8 @@ completeWelcomeText = '''\
 - **%(overview41)s**: %(overview42)s
 
 
-=== %(text_entry)s ===
-%(text_entry_par)s
-
-%(example_entry)s
+=== %(preview)s ===
+%(preview_par)s
 
 === %(annotations)s ===
 %(ann_par)s
@@ -152,9 +153,6 @@ completeWelcomeText = '''\
 === %(save)s ===
 %(save_par)s
 
-=== %(help)s ===
-%(help_par)s
-
 %(error_par)s
 
 %(goodbye_par)s''' % globals()
@@ -195,9 +193,9 @@ get a list of the cool stuff that happened to me with the respective dates.
 Additionally you can select the "Cool Stuff" category in the word cloud window \
 to get a list of all the cool things.
 
-Maybe a good thing to know is the following: 
+Maybe a good thing to know is the following:
 "Tags" is a category, the tagnames are entries in the category "Tags", \
-distributed over various days. 
+distributed over various days.
 Similarly you can have a category "Movies" and add it together with \
 the movie's name to every day on which you see a new film.
 
@@ -210,8 +208,7 @@ u'Tags': {u'Documentation': None, u'Projects': None},
 u'Todo': {u'**Wash the dishes**': None},
 }
 
-example_day2 = {
-'text': '''\
+multiple_entries_text = '''\
 === Multiple Entries ===
 You can add multiple entries to one day in two ways:
 - Use two different journals (one named “Work”, the other “Play”)
@@ -219,6 +216,9 @@ You can add multiple entries to one day in two ways:
 - Use a horizontal separator line (20 “=”s)
 
 
+'''
+
+multiple_entries_example = '''\
 ====================
 
 === Work ===
@@ -227,7 +227,11 @@ Here goes the first entry.
 ====================
 
 === Play ===
-Here comes the entry about the fun stuff.''',
+Here comes the entry about the fun stuff.
+'''
+
+example_day2 = {
+'text': multiple_entries_text + multiple_entries_example,
 u'Tags': {u'Documentation': None, u'Work': None, u'Play': None},}
 
 example_day3 = {
@@ -269,40 +273,50 @@ u'Done': {u'--Check mail--': None,},
 example_content = [welcome_day, example_day1, example_day2, example_day3]
 
 ann_help_text = example_day1['text'].replace('===', '==')
-
-multiple_entries_text = example_day2['text']
-multiple_entries_text = multiple_entries_text.replace('=== Work ===', '**Work**\n')
-multiple_entries_text = multiple_entries_text.replace('=== Play ===', '**Play**\n')
-
 todo_help_text = example_day3['text']
 
 
 help_text = '''
-==== Text ====
+== Layout ==
+%(overview1)s
+- **%(overview21)s**: %(overview22)s
+- **%(overview31)s**: %(overview32)s
+- **%(overview41)s**: %(overview42)s
+
+
+%(preview1)s
+
+== Text ==
 The main text field is the container for your normal diary entries like this one:
 
 %(example_entry)s
 
-==== Format ====
+== Format ==
 As you see, the text can be formatted **bold**, \
 //italic//, --struck through-- and __underlined__. As a convenience there \
-is also the "Format" button, with which you can format the main text and nodes \
+is also the "Format" button, with which you can format the main text and entries \
 in the categories tree on the right.
 
-A blank line starts a new **paragraph**, \\\\ results in a newline.
-
-%% Formatting commands inside two pairs of "" are not interpreted (""**not bold**"")
-
-**Comments** can be inserted after percent signs (**%%**). They will not be shown in the \
-preview and the exports. The %% has to be the first character on the line.
+A blank line starts a new **paragraph**, two backslashes\\\\ result in a **newline**.
 
 To see the result, click on the "Preview" button.
 You can also see how \
 this text was formatted by looking at its [source source.txt].
 
+**Lists** can be created by using the following style, If you use "+"
+instead of "-" you can create a **numbered list**.
+
+```
+- First Item
+  - Indented Item
+- Do not forget two blank lines after a list
+
+
+```
+
 %(ann_help_text)s
 
-==== Images, Files and Links ====
+== Images, Files and Links ==
 RedNotebook lets you insert images, files and links into your entries. \
 To do so, select the appropriate option in the "Insert" pull-down menu \
 above the main text field. The text will be inserted at the current \
@@ -311,14 +325,14 @@ cursor position.
 With the insert button you cannot insert **links to directories** on your computer. \
 Those can be inserted manually however (""[Home ""file:///home/""]"").
 
-==== %(templates)s ====
-%(temp_par)s 
+== %(templates)s ==
+%(temp_par)s
 The files 1.txt to 7.txt in the template directory correspond to the templates \
 for each day of the week. The current weekday's template will be filled \
 into the text area when you click on "Template". You can open the template files \
 from inside RedNotebook by opening the menu next to the "Template" button.
 
-==== Tags ====
+== Tags ==
 Tagging an entry (e.g. with the tag "Work") is also easy: \
 On the right, click on "Add Tag" and insert \
 "Work" into the lower textbox. The result looks like:
@@ -331,18 +345,18 @@ You can see a tag cloud on the left by activating the "Clouds" tab and \
 selecting "Tags". Get a list of all tags with a given name by clicking \
 on that tag in the cloud.
 
-==== Search ====
+== Search ==
 On the left you find the search box. You can search for text, display a \
 category's content or show all days with a given tag. \
 Double-clicking on a day lets you jump to it.
 
-==== Clouds ====
+== Clouds ==
 Clicking on the "Clouds" tab on the left lets you view the most often used words in your journal.
 You can select to view your category or tag clouds by clicking on the scroll-down menu.
 If words appear in the cloud that you don't want to see there, just right-click on them. \
 Alternatively you can open the Preferences dialog and add the words to the cloud blacklist there.
 
-==== Spellcheck ====
+== Spellcheck ==
 RedNotebook supports spellchecking your entries if you have \
 python-gtkspell installed (Only available on Linux). \
 To highlight all misspelled words in your entries, select the corresponding option in \
@@ -351,20 +365,20 @@ the preferences window.
 Since gtkspell 2.0.15, you can select the spellchecking language by right-clicking on the \
 main text area (in edit mode) and choosing it from the submenu "Languages".
 
-==== Options ====
+== Options ==
 Make sure you check out the customizable options in the Preferences dialog. You can
 open this dialog by clicking on the entry in the "Edit" menu.
 
-==== Save ====
+== Save ==
 %(save1)s %(save2)s %(save3)s
 
-==== Export ====
+== Export ==
 %(save4)s %(save5)s
 
 Since version 0.9.2 you can also directly export your journal to PDF. If the \
 option does not show up in the export assistant, you need to install \
 pywebkitgtk version 1.1.5 or later (the package is sometime called \
-python-webkit). 
+python-webkit).
 
 **Latex caveats**
 
@@ -374,7 +388,7 @@ Make sure to type all links with the full path including the protocol:
 - file:///home/sam/myfile.txt (--/home/sam/myfile.txt--)
 
 
-==== Synchronize across multiple computers ====[sync]
+== Synchronize across multiple computers ==[sync]
 Syncing RedNotebook with a remote server is easy. You can either use a \
 cloud service like Ubuntu One or Dropbox or save your journal to your \
 own server.
@@ -417,12 +431,12 @@ the file "rednotebook/files/default.cfg". There you can set the value of \
 userDir to the path where you want to share your settings between the \
 systems.
 
-==== Portable mode ====
+== Portable mode ==
 RedNotebook can be run in portable mode. In this mode, the \
 template directory and the configuration and log file are saved \
 in the application directory instead of in the home directory. \
 Additionally the path to the last opened journal is remembered \
-relatively to the application directory. 
+relatively to the application directory.
 
 To use RedNotebook on a flash drive on Windows, run the installer and \
 select a directory on your USB drive as the installation directory. \
@@ -432,14 +446,14 @@ portable mode.
 To **activate portable mode**, change into the files/ directory and in the \
 default.cfg file set portable=1.
 
-=== Convert Latex output to PDF ===
+== Convert Latex output to PDF ==
 
 In recent RedNotebook versions you can export your journal directly to PDF, \
 so this section may be obsolete. \
 However, there may be some people who prefer to export their \
 journal to Latex first and convert it to PDF later. Here is how you do it:
 
-== Linux ==
+=== Linux ===
 
 For the conversion on Linux you need some extra packages: texlive-latex-base and \
 texlive-latex-recommended. Maybe you also need texlive-latex-extra. Those contain \
@@ -447,7 +461,7 @@ the pdflatex program and are available in the repositories of most Linux distros
 
 You can convert the .tex file by typing the following text in a command line: \
 
-"""pdflatex your-rednotebook-export.tex"""
+``pdflatex your-rednotebook-export.tex``
 
 Alternatively you can install a Latex editor like Kile \
 (http://kile.sourceforge.net/), open the .tex file with it and hit the export \
@@ -462,7 +476,7 @@ If you run into any problems during the conversion, the easiest way to solve \
 them is to install a latex editor and do the conversion with it. That way \
 you can see the errors right away and get rid of them by editing the file.
 
-== Windows ==
+=== Windows ===
 
 You can open an exported Latex file with Texniccenter and convert it to PDF \
 with MikTex. Visit www.texniccenter.org/ and www.miktex.org \
@@ -471,7 +485,7 @@ open the .tex file with Texniccenter and select "Build Output" from the \
 "Output" menu. The program will then create the beautifully looking PDF in the
 same directory.
 
-==== Keyboard Shortcuts ====
+== Keyboard Shortcuts ==
 ||   Action          |   Shortcut             |
 | Preview (On/Off)   | <Ctrl> + P             |
 | Find               | <Ctrl> + F             |
@@ -484,7 +498,7 @@ same directory.
 
 You can find other shortcuts in the menus.
 
-==== Encryption ====
+== Encryption ==
 You can use e.g. [TrueCrypt http://www.truecrypt.org] to encrypt your \
 journal. Nick Bair has written a nice tutorial about \
 [encrypting RedNotebook files \
@@ -500,7 +514,7 @@ This method is especially useful for laptop users, because their \
 computers are more likely to be stolen. If you encrypt your home \
 partition all RedNotebook data will be encrypted, too.
 
-==== Tips ====
+== Tips ==
 %(multiple_entries_text)s
 
 %(todo_help_text)s
@@ -520,8 +534,25 @@ On Linux, start a terminal and call ``LANG=de_DE.utf8``. Then in the \
 same terminal, run ``rednotebook``. The language change will be gone \
 however once you close the terminal.
 
-On Windows, set or create a PATH environment variable with the desired \
-code.
+On Windows, set or create a LANG environment variable with the desired \
+code:
+
++ Right-click My Computer and click Properties.
++ In the System Properties window, click on the Advanced tab.
++ In the Advanced section, click the Environment Variables button.
++ Click the New button and insert LANG at the top and e.g. de or de_DE or
+  de_DE.UTF-8 (use your [language code ""http://en.wikipedia.org/wiki/ISO_639-1""]).
+
+
+=== Titles ===
+You can insert titles into your post by adding "="s around your title
+text. = My Title = is the biggest heading, ====== My Title ====== is
+the smallest heading. A title line can only contain the title, nothing
+else.
+
+Numbered titles can be created by using "+" instead of "=".
+""+ My Title +"" produces a title like "1.", ++++++ My Title ++++++
+produces a title like 0.0.0.0.0.1
 
 === Insert HTML or Latex code ===
 To insert custom code into your entries surround the code with single \
@@ -538,13 +569,13 @@ This feature can be used to insert e.g. latex formulas:
 
 ```
 \'''
-$$\sum_{i=1}^{n} i = \\frac{n \cdot (n+1)}{2}$$
+==\sum_{i=1}^{n} i = \\frac{n \cdot (n+1)}{2}==
 \'''
 ```
 
 will produce a nice looking formula in the Latex export.
 
-=== Insert verbatim text (Preserve format) ===
+=== Verbatim text (Preserve format) ===
 To insert preformatted text preserving newlines and spaces, you can \
 use the backquotes (`). Use 2 backquotes for inline insertions and 3 \
 backquotes if you want to insert a whole paragraph. \
@@ -564,12 +595,19 @@ robot = Robot()
 robot.greet()
 ```
 
+=== Unparsed text ===
+Formatting commands inside two pairs of "" are not interpreted (""**not bold**"").
+
+=== Comments ===
+Comments can be inserted after percent signs (**%%**). They will not be shown in the \
+preview and the exports. The %% has to be the first character on the line.
+
 === List of all Entries ===
 To get a list of all entries, just search for " " (the space character). \
 This character is most likely included in all entries. You can sort the \
 resulting list chronologically by pressing the "Date" button.
 
-==== Command line options ====
+== Command line options ==
 ```
 Usage: rednotebook [options] [journal-path]
 
@@ -592,7 +630,7 @@ Options:
   -m, --minimized   Start mimimized to system tray (default: False)
 ```
 
-==== Data Format ====
+== Data Format ==
 In this paragraph I will explain shortly what the RedNotebook files \
 consist of. Firstly it is important to understand that the content \
 is saved in a directory with many files, not just one file. \
@@ -600,7 +638,7 @@ The directory name is used as a name for the journal.
 
 In the directory there are several files all conforming to the naming \
 scheme "2010-05.txt" (<year>-<month>.txt). Obviously these files \
-correspond to months (May 2010). 
+correspond to months (May 2010).
 
 Each month file contains text for the days of that month. \
 The text is actually [YAML www.yaml.org] markup. Without the \
@@ -621,12 +659,12 @@ the main content area. Additionally there can be multiple other keys \
 that stand for the categories that belong to that day. Each category \
 contains a dictionary with only one key, the category entry.
 
-==== Questions ====
+== Questions ==
 If you have any questions or comments, feel free to post them in the \
 [forum http://apps.sourceforge.net/phpbb/rednotebook/] or \
 contact me directly.
 
-==== Bugs ====
+== Bugs ==
 There is no software without bugs, so if you encounter one please drop me a note.
 This way RedNotebook can get better not only for you, but for all users.
 
@@ -653,14 +691,14 @@ def write_documentation(dir):
     Write the documenation as html to a directory
     Include the original markup as "source.txt"
     '''
-    from rednotebook.util import utils
+    from rednotebook.util import filesystem
     from rednotebook.util import markup
 
-    utils.write_file(help_text, os.path.join(dir, 'source.txt'))
+    filesystem.write_file(os.path.join(dir, 'source.txt'), help_text)
     headers = [_('RedNotebook Documentation'), version, '']
     options = {'toc': 1,}
     html = markup.convert(help_text, 'xhtml', headers, options)
-    utils.write_file(html, os.path.join(dir, 'help.html'))
+    filesystem.write_file(os.path.join(dir, 'help.html'), html)
 
 if __name__ == '__main__':
     import sys
@@ -668,7 +706,7 @@ if __name__ == '__main__':
 
     print completeWelcomeText
     print '*'*80
-    print helpText
+    print help_text
 
     doc_dir = '../doc'
     doc_dir = os.path.abspath(doc_dir)
